/**
 * \file  hw_syscfg0_C6748.h
 *
 * \brief Hardware registers and fields for SYSCFG0 module
 */

/*
* Copyright (C) 2010 Texas Instruments Incorporated - http://www.ti.com/
*/
/*
*  Redistribution and use in source and binary forms, with or without
*  modification, are permitted provided that the following conditions
*  are met:
*
*    Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*
*    Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in the
*    documentation and/or other materials provided with the
*    distribution.
*
*    Neither the name of Texas Instruments Incorporated nor the names of
*    its contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
*  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
*  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
*  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
*  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
*  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
*  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
*  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
*  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*/


#ifndef _HW_SYSCFG0_H_
#define _HW_SYSCFG0_H_

#ifdef __cplusplus
extern "C" {
#endif

#define SYSCFG0_REVID		(0x0)
#define SYSCFG0_DIEIDR0		(0x8)
#define SYSCFG0_DIEIDR1		(0xC)
#define SYSCFG0_DIEIDR2		(0x10)
#define SYSCFG0_DIEIDR3		(0x14)
#define SYSCFG0_DEVIDR0		(0x18)
#define SYSCFG0_BOOTCFG		(0x20)
#define SYSCFG0_KICK0R		(0x38)
#define SYSCFG0_KICK1R		(0x3C)
#define SYSCFG0_HOST0CFG	(0x40)
#define SYSCFG0_IRAWSTAT	(0xE0)
#define SYSCFG0_IENSTAT		(0xE4)
#define SYSCFG0_IENSET		(0xE8)
#define SYSCFG0_IENCLR		(0xEC)
#define SYSCFG0_EOI		(0xF0)
#define SYSCFG0_FLTADDRR	(0xF4)
#define SYSCFG0_FLTSTAT		(0xF8)
#define SYSCFG0_MSTPRI0		(0x110)
#define SYSCFG0_MSTPRI1		(0x114)
#define SYSCFG0_MSTPRI2		(0x118)
#define SYSCFG0_PINMUX(n)	(0x120 + (n * 4))
#define SYSCFG0_SUSPSRC		(0x170)
#define SYSCFG0_CHIPSIG		(0x174)
#define SYSCFG0_CHIPSIG_CLR	(0x178)
#define SYSCFG0_CFGCHIP0	(0x17C)
#define SYSCFG0_CFGCHIP1	(0x180)
#define SYSCFG0_CFGCHIP2	(0x184)
#define SYSCFG0_CFGCHIP3	(0x188)
#define SYSCFG0_CFGCHIP4	(0x18C)

/******************************************************************************
**                      FIELD DEFINITION MACROS
******************************************************************************/

/* REVID */

#define SYSCFG_REVID_REVID      (0xFFFFFFFFu)
#define SYSCFG_REVID_REVID_SHIFT     (0x00000000u)


/* DIEIDR0 */

#define SYSCFG_DIEIDR0_DIEID0   (0xFFFFFFFFu)
#define SYSCFG_DIEIDR0_DIEID0_SHIFT  (0x00000000u)


/* DIEIDR1 */

#define SYSCFG_DIEIDR1_DIEID1   (0xFFFFFFFFu)
#define SYSCFG_DIEIDR1_DIEID1_SHIFT  (0x00000000u)


/* DIEIDR2 */

#define SYSCFG_DIEIDR2_DIEID2   (0xFFFFFFFFu)
#define SYSCFG_DIEIDR2_DIEID2_SHIFT  (0x00000000u)


/* DIEIDR3 */

#define SYSCFG_DIEIDR3_DIEID3   (0xFFFFFFFFu)
#define SYSCFG_DIEIDR3_DIEID3_SHIFT  (0x00000000u)


/* DEVIDR0 */

#define SYSCFG_DEVIDR0_DEVID0   (0xFFFFFFFFu)
#define SYSCFG_DEVIDR0_DEVID0_SHIFT  (0x00000000u)


/* BOOTCFG */


#define SYSCFG_BOOTCFG_SMARTRFLX (0x0FFF0000u)
#define SYSCFG_BOOTCFG_SMARTRFLX_SHIFT (0x00000010u)

#define SYSCFG_BOOTCFG_BOOTMODE (0x0000FFFFu)
#define SYSCFG_BOOTCFG_BOOTMODE_SHIFT (0x00000000u)


/* CHIPREVIDR */


#define SYSCFG_CHIPREVIDR_CHIPREVID (0x0000003Fu)
#define SYSCFG_CHIPREVIDR_CHIPREVID_SHIFT (0x00000000u)


/* KICK0R */

#define SYSCFG_KICK0R_KICK0     (0xFFFFFFFFu)
#define SYSCFG_KICK0R_KICK0_SHIFT    (0x00000000u)

/* Unlock/Lock code for KICK0 */
#define SYSCFG_KICK0R_UNLOCK    (0x83E70B13u)


/* KICK1R */

#define SYSCFG_KICK1R_KICK1     (0xFFFFFFFFu)
#define SYSCFG_KICK1R_KICK1_SHIFT    (0x00000000u)

/* Unlock/Lock code for KICK1 */
#define SYSCFG_KICK1R_UNLOCK    (0x95A4F1E0u)

/* HOST0CFG */

#define SYSCFG_HOST0CFG_BOOTRDY (0x80000000u)
#define SYSCFG_HOST0CFG_BOOTRDY_SHIFT (0x0000001Fu)



/* HOST1CFG */

#define SYSCFG_HOST1CFG_BOOTRDY (0x80000000u)
#define SYSCFG_HOST1CFG_BOOTRDY_SHIFT (0x0000001Fu)


#define SYSCFG_HOST1CFG_DSP_ISTP_RST_VAL (0x003FFFFFu)
#define SYSCFG_HOST1CFG_DSP_ISTP_RST_VAL_SHIFT (0x00000000u)


/* IRAWSTAT */


#define SYSCFG_IRAWSTAT_ADDRERR (0x00000002u)
#define SYSCFG_IRAWSTAT_ADDRERR_SHIFT (0x00000001u)

#define SYSCFG_IRAWSTAT_PROTERR (0x00000001u)
#define SYSCFG_IRAWSTAT_PROTERR_SHIFT (0x00000000u)


/* IENSTAT */


#define SYSCFG_IENSTAT_ADDRERR  (0x00000002u)
#define SYSCFG_IENSTAT_ADDRERR_SHIFT (0x00000001u)

#define SYSCFG_IENSTAT_PROTERR  (0x00000001u)
#define SYSCFG_IENSTAT_PROTERR_SHIFT (0x00000000u)


/* IENSET */


#define SYSCFG_IENSET_ADDRERR_EN (0x00000002u)
#define SYSCFG_IENSET_ADDRERR_EN_SHIFT (0x00000001u)

#define SYSCFG_IENSET_PROTERR_EN (0x00000001u)
#define SYSCFG_IENSET_PROTERR_EN_SHIFT (0x00000000u)


/* IENCLR */


#define SYSCFG_IENCLR_ADDRERR_CLR (0x00000002u)
#define SYSCFG_IENCLR_ADDRERR_CLR_SHIFT (0x00000001u)

#define SYSCFG_IENCLR_PROTERR_CLR (0x00000001u)
#define SYSCFG_IENCLR_PROTERR_CLR_SHIFT (0x00000000u)


/* EOI */


#define SYSCFG_EOI_EOIVECT      (0x000000FFu)
#define SYSCFG_EOI_EOIVECT_SHIFT     (0x00000000u)


/* FLTADDRR */

#define SYSCFG_FLTADDRR_FLTADDR (0xFFFFFFFFu)
#define SYSCFG_FLTADDRR_FLTADDR_SHIFT (0x00000000u)


/* FLTSTAT */

#define SYSCFG_FLTSTAT_ID       (0xFF000000u)
#define SYSCFG_FLTSTAT_ID_SHIFT      (0x00000018u)

#define SYSCFG_FLTSTAT_MSTID    (0x00FF0000u)
#define SYSCFG_FLTSTAT_MSTID_SHIFT   (0x00000010u)


#define SYSCFG_FLTSTAT_PRIVID   (0x00001E00u)
#define SYSCFG_FLTSTAT_PRIVID_SHIFT  (0x00000009u)


#define SYSCFG_FLTSTAT_NOSECACC (0x00000080u)
#define SYSCFG_FLTSTAT_NOSECACC_SHIFT (0x00000007u)


#define SYSCFG_FLTSTAT_TYPE     (0x0000003Fu)
#define SYSCFG_FLTSTAT_TYPE_SHIFT    (0x00000000u)
/*----TYPE Tokens----*/
#define SYSCFG_FLTSTAT_TYPE_NOFLT    (0x00000000u)
#define SYSCFG_FLTSTAT_TYPE_USREXE   (0x00000001u)
#define SYSCFG_FLTSTAT_TYPE_USRWR    (0x00000002u)
#define SYSCFG_FLTSTAT_TYPE_USRRD    (0x00000004u)
#define SYSCFG_FLTSTAT_TYPE_SPREXE   (0x00000008u)
#define SYSCFG_FLTSTAT_TYPE_SPRWR    (0x00000010u)
#define SYSCFG_FLTSTAT_TYPE_SPRRD    (0x00000020u)


/* MSTPRI0 */


#define SYSCFG_MSTPRI0_SATA     (0x00700000u)
#define SYSCFG_MSTPRI0_SATA_SHIFT    (0x00000014u)


#define SYSCFG_MSTPRI0_UPP      (0x00070000u)
#define SYSCFG_MSTPRI0_UPP_SHIFT     (0x00000010u)


#define SYSCFG_MSTPRI0_DSP_CFG  (0x00007000u)
#define SYSCFG_MSTPRI0_DSP_CFG_SHIFT (0x0000000Cu)


#define SYSCFG_MSTPRI0_DSP_MDMA (0x00000700u)
#define SYSCFG_MSTPRI0_DSP_MDMA_SHIFT (0x00000008u)


#define SYSCFG_MSTPRI0_ARM_D    (0x00000070u)
#define SYSCFG_MSTPRI0_ARM_D_SHIFT   (0x00000004u)


#define SYSCFG_MSTPRI0_ARM_I    (0x00000007u)
#define SYSCFG_MSTPRI0_ARM_I_SHIFT   (0x00000000u)


/* MSTPRI1 */


#define SYSCFG_MSTPRI1_VPIF_DMA_1 (0x70000000u)
#define SYSCFG_MSTPRI1_VPIF_DMA_1_SHIFT (0x0000001Cu)


#define SYSCFG_MSTPRI1_VPIF_DMA_0 (0x07000000u)
#define SYSCFG_MSTPRI1_VPIF_DMA_0_SHIFT (0x00000018u)


#define SYSCFG_MSTPRI1_EDMA31TC0 (0x00070000u)
#define SYSCFG_MSTPRI1_EDMA31TC0_SHIFT (0x00000010u)


#define SYSCFG_MSTPRI1_EDMA30TC1 (0x00007000u)
#define SYSCFG_MSTPRI1_EDMA30TC1_SHIFT (0x0000000Cu)


#define SYSCFG_MSTPRI1_EDMA30TC0 (0x00000700u)
#define SYSCFG_MSTPRI1_EDMA30TC0_SHIFT (0x00000008u)


#define SYSCFG_MSTPRI1_PRU1     (0x00000070u)
#define SYSCFG_MSTPRI1_PRU1_SHIFT    (0x00000004u)


#define SYSCFG_MSTPRI1_PRU0     (0x00000007u)
#define SYSCFG_MSTPRI1_PRU0_SHIFT    (0x00000000u)


/* MSTPRI2 */


#define SYSCFG_MSTPRI2_LCDC     (0x70000000u)
#define SYSCFG_MSTPRI2_LCDC_SHIFT    (0x0000001Cu)


#define SYSCFG_MSTPRI2_USB1     (0x07000000u)
#define SYSCFG_MSTPRI2_USB1_SHIFT    (0x00000018u)


#define SYSCFG_MSTPRI2_UHPI     (0x00700000u)
#define SYSCFG_MSTPRI2_UHPI_SHIFT    (0x00000014u)


#define SYSCFG_MSTPRI2_USB0CDMA (0x00007000u)
#define SYSCFG_MSTPRI2_USB0CDMA_SHIFT (0x0000000Cu)


#define SYSCFG_MSTPRI2_USB0CFG  (0x00000700u)
#define SYSCFG_MSTPRI2_USB0CFG_SHIFT (0x00000008u)


#define SYSCFG_MSTPRI2_EMAC     (0x00000007u)
#define SYSCFG_MSTPRI2_EMAC_SHIFT    (0x00000000u)


/* PINMUX0 */

#define SYSCFG_PINMUX0_PINMUX0_31_28 (0xF0000000u)
#define SYSCFG_PINMUX0_PINMUX0_31_28_SHIFT (0x0000001Cu)
/*----PINMUX0_31_28 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_31_28_RESERVED1 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_31_28_ALARM (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_31_28_UART2_CTS (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_31_28_GPIO0_8 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_27_24 (0x0F000000u)
#define SYSCFG_PINMUX0_PINMUX0_27_24_SHIFT (0x00000018u)
/*----PINMUX0_27_24 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_27_24_AMUTE0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_27_24_PRU0_R30_16 (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_27_24_UART2_RTS (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_27_24_GPIO0_9 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_23_20 (0x00F00000u)
#define SYSCFG_PINMUX0_PINMUX0_23_20_SHIFT (0x00000014u)
/*----PINMUX0_23_20 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_23_20_AHCLKX0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_23_20_USB_REFCLKIN (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_23_20_UART1_CTS (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_23_20_GPIO0_10 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_19_16 (0x000F0000u)
#define SYSCFG_PINMUX0_PINMUX0_19_16_SHIFT (0x00000010u)
/*----PINMUX0_19_16 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_19_16_AHCLKR0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_19_16_PRU0_R30_18 (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_19_16_UART1_RTS (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_19_16_GPIO0_11 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_15_12 (0x0000F000u)
#define SYSCFG_PINMUX0_PINMUX0_15_12_SHIFT (0x0000000Cu)
/*----PINMUX0_15_12 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_15_12_AFSX0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_15_12_OBSERVE0_LOS (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_15_12_GPIO0_12 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_11_8 (0x00000F00u)
#define SYSCFG_PINMUX0_PINMUX0_11_8_SHIFT (0x00000008u)
/*----PINMUX0_11_8 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_11_8_AFSR0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_11_8_OBSERVE0_SYNC (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_11_8_GPIO0_13 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_7_4 (0x000000F0u)
#define SYSCFG_PINMUX0_PINMUX0_7_4_SHIFT (0x00000004u)
/*----PINMUX0_7_4 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_7_4_ACLKX0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_7_4_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_7_4_PRU0_R30_19 (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_7_4_GPIO0_14 (0x00000008u)

#define SYSCFG_PINMUX0_PINMUX0_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX0_PINMUX0_3_0_SHIFT (0x00000000u)
/*----PINMUX0_3_0 Tokens----*/
#define SYSCFG_PINMUX0_PINMUX0_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX0_PINMUX0_3_0_ACLKR0 (0x00000001u)
#define SYSCFG_PINMUX0_PINMUX0_3_0_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX0_PINMUX0_3_0_PRU0_R30_20 (0x00000004u)
#define SYSCFG_PINMUX0_PINMUX0_3_0_GPIO0_15 (0x00000008u)


/* PINMUX1 */

#define SYSCFG_PINMUX1_PINMUX1_31_28 (0xF0000000u)
#define SYSCFG_PINMUX1_PINMUX1_31_28_SHIFT (0x0000001Cu)
/*----PINMUX1_31_28 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_31_28_AXR0_8 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_31_28_CLKS1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_31_28_ECAP1 (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_31_28_GPIO0_0 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_27_24 (0x0F000000u)
#define SYSCFG_PINMUX1_PINMUX1_27_24_SHIFT (0x00000018u)
/*----PINMUX1_27_24 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_27_24_AXR0_9 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_27_24_DX1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_27_24_OBSERVE0_PHY_STATE2 (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_27_24_GPIO0_1 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_23_20 (0x00F00000u)
#define SYSCFG_PINMUX1_PINMUX1_23_20_SHIFT (0x00000014u)
/*----PINMUX1_23_20 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_23_20_AXR0_10 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_23_20_DR1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_23_20_OBSERVE0_PHY_STATE1 (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_23_20_GPIO0_2 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_19_16 (0x000F0000u)
#define SYSCFG_PINMUX1_PINMUX1_19_16_SHIFT (0x00000010u)
/*----PINMUX1_19_16 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_19_16_AXR0_11 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_19_16_FSX1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_19_16_OBSERVE0_PHY_STATE0 (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_19_16_GPIO0_3 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_15_12 (0x0000F000u)
#define SYSCFG_PINMUX1_PINMUX1_15_12_SHIFT (0x0000000Cu)
/*----PINMUX1_15_12 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_15_12_AXR0_12 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_15_12_FSR1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_15_12_OBSERVE0_PHY_READY (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_15_12_GPIO0_4 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_11_8 (0x00000F00u)
#define SYSCFG_PINMUX1_PINMUX1_11_8_SHIFT (0x00000008u)
/*----PINMUX1_11_8 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_11_8_AXR0_13 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_11_8_CLKX1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_11_8_OBSERVE0_COMINIT (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_11_8_GPIO0_5 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_7_4 (0x000000F0u)
#define SYSCFG_PINMUX1_PINMUX1_7_4_SHIFT (0x00000004u)
/*----PINMUX1_7_4 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_7_4_AXR0_14 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_7_4_CLKR1 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_7_4_OBSERVE0_COMWAKE (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_7_4_GPIO0_6 (0x00000008u)

#define SYSCFG_PINMUX1_PINMUX1_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX1_PINMUX1_3_0_SHIFT (0x00000000u)
/*----PINMUX1_3_0 Tokens----*/
#define SYSCFG_PINMUX1_PINMUX1_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX1_PINMUX1_3_0_AXR0_15 (0x00000001u)
#define SYSCFG_PINMUX1_PINMUX1_3_0_EPWM0TZ0 (0x00000002u)
#define SYSCFG_PINMUX1_PINMUX1_3_0_ECAP2 (0x00000004u)
#define SYSCFG_PINMUX1_PINMUX1_3_0_GPIO0_7 (0x00000008u)


/* PINMUX2 */

#define SYSCFG_PINMUX2_PINMUX2_31_28 (0xF0000000u)
#define SYSCFG_PINMUX2_PINMUX2_31_28_SHIFT (0x0000001Cu)
/*----PINMUX2_31_28 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_31_28_AXR0_0 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_31_28_ECAP0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_31_28_GPIO8_7 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_31_28_MII_TXD0 (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_27_24 (0x0F000000u)
#define SYSCFG_PINMUX2_PINMUX2_27_24_SHIFT (0x00000018u)
/*----PINMUX2_27_24 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_27_24_AXR0_1 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_27_24_DX0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_27_24_GPIO1_9 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_27_24_MII_TXD1 (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_23_20 (0x00F00000u)
#define SYSCFG_PINMUX2_PINMUX2_23_20_SHIFT (0x00000014u)
/*----PINMUX2_23_20 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_23_20_AXR0_2 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_23_20_DR0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_23_20_GPIO1_10 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_23_20_MII_TXD2 (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_19_16 (0x000F0000u)
#define SYSCFG_PINMUX2_PINMUX2_19_16_SHIFT (0x00000010u)
/*----PINMUX2_19_16 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_19_16_AXR0_3 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_19_16_FSX0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_19_16_GPIO1_11 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_19_16_MII_TXD3 (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_15_12 (0x0000F000u)
#define SYSCFG_PINMUX2_PINMUX2_15_12_SHIFT (0x0000000Cu)
/*----PINMUX2_15_12 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_15_12_AXR0_4 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_15_12_FSR0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_15_12_GPIO1_12 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_15_12_MII_COL (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_11_8 (0x00000F00u)
#define SYSCFG_PINMUX2_PINMUX2_11_8_SHIFT (0x00000008u)
/*----PINMUX2_11_8 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_11_8_AXR0_5 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_11_8_CLKX0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_11_8_GPIO1_13 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_11_8_MII_TXCLK (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_7_4 (0x000000F0u)
#define SYSCFG_PINMUX2_PINMUX2_7_4_SHIFT (0x00000004u)
/*----PINMUX2_7_4 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_7_4_AXR0_6 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_7_4_CLKR0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_7_4_GPIO1_14 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_7_4_MII_TXEN (0x00000008u)

#define SYSCFG_PINMUX2_PINMUX2_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX2_PINMUX2_3_0_SHIFT (0x00000000u)
/*----PINMUX2_3_0 Tokens----*/
#define SYSCFG_PINMUX2_PINMUX2_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX2_PINMUX2_3_0_AXR0_7 (0x00000001u)
#define SYSCFG_PINMUX2_PINMUX2_3_0_EPWM1TZ0 (0x00000002u)
#define SYSCFG_PINMUX2_PINMUX2_3_0_PRU0_R30_17 (0x00000004u)
#define SYSCFG_PINMUX2_PINMUX2_3_0_GPIO1_15 (0x00000008u)


/* PINMUX3 */

#define SYSCFG_PINMUX3_PINMUX3_31_28 (0xF0000000u)
#define SYSCFG_PINMUX3_PINMUX3_31_28_SHIFT (0x0000001Cu)
/*----PINMUX3_31_28 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_31_28_NSPI0_SCS2 (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_31_28_UART0_RTS (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_31_28_GPIO8_1 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_31_28_MII_RXD0 (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_27_24 (0x0F000000u)
#define SYSCFG_PINMUX3_PINMUX3_27_24_SHIFT (0x00000018u)
/*----PINMUX3_27_24 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_27_24_NSPI0_SCS3 (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_27_24_UART0_CTS (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_27_24_GPIO8_2 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_27_24_MII_RXD1 (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_23_20 (0x00F00000u)
#define SYSCFG_PINMUX3_PINMUX3_23_20_SHIFT (0x00000014u)
/*----PINMUX3_23_20 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_23_20_NSPI0_SCS4 (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_23_20_UART0_TXD (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_23_20_GPIO8_3 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_23_20_MII_RXD2 (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_19_16 (0x000F0000u)
#define SYSCFG_PINMUX3_PINMUX3_19_16_SHIFT (0x00000010u)
/*----PINMUX3_19_16 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_19_16_NSPI0_SCS5 (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_19_16_UART0_RXD (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_19_16_GPIO8_4 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_19_16_MII_RXD3 (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_15_12 (0x0000F000u)
#define SYSCFG_PINMUX3_PINMUX3_15_12_SHIFT (0x0000000Cu)
/*----PINMUX3_15_12 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_15_12_SPI0_SIMO0 (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_15_12_EPWMSYNCO (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_15_12_GPIO8_5 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_15_12_MII_CRS (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_11_8 (0x00000F00u)
#define SYSCFG_PINMUX3_PINMUX3_11_8_SHIFT (0x00000008u)
/*----PINMUX3_11_8 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_11_8_SPI0_SOMI0 (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_11_8_EPWMSYNCI (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_11_8_GPIO8_6 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_11_8_MII_RXER (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_7_4 (0x000000F0u)
#define SYSCFG_PINMUX3_PINMUX3_7_4_SHIFT (0x00000004u)
/*----PINMUX3_7_4 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_7_4_NSPI0_ENA (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_7_4_EPWM0B (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_7_4_PRU0_R30_6 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_7_4_MII_RXDV (0x00000008u)

#define SYSCFG_PINMUX3_PINMUX3_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX3_PINMUX3_3_0_SHIFT (0x00000000u)
/*----PINMUX3_3_0 Tokens----*/
#define SYSCFG_PINMUX3_PINMUX3_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX3_PINMUX3_3_0_SPI0_CLK (0x00000001u)
#define SYSCFG_PINMUX3_PINMUX3_3_0_EPWM0A (0x00000002u)
#define SYSCFG_PINMUX3_PINMUX3_3_0_GPIO1_8 (0x00000004u)
#define SYSCFG_PINMUX3_PINMUX3_3_0_MII_RXCLK (0x00000008u)


/* PINMUX4 */

#define SYSCFG_PINMUX4_PINMUX4_31_28 (0xF0000000u)
#define SYSCFG_PINMUX4_PINMUX4_31_28_SHIFT (0x0000001Cu)
/*----PINMUX4_31_28 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_31_28_NSPI1_SCS2 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_31_28_UART1_TXD (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_31_28_CP_POD (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_31_28_GPIO1_0 (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_27_24 (0x0F000000u)
#define SYSCFG_PINMUX4_PINMUX4_27_24_SHIFT (0x00000018u)
/*----PINMUX4_27_24 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_27_24_NSPI1_SCS3 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_27_24_UART1_RXD (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_27_24_LED (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_27_24_GPIO1_1 (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_23_20 (0x00F00000u)
#define SYSCFG_PINMUX4_PINMUX4_23_20_SHIFT (0x00000014u)
/*----PINMUX4_23_20 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_23_20_NSPI1_SCS4 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_23_20_UART2_TXD (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_23_20_I2C1_SDA (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_23_20_GPIO1_2 (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_19_16 (0x000F0000u)
#define SYSCFG_PINMUX4_PINMUX4_19_16_SHIFT (0x00000010u)
/*----PINMUX4_19_16 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_19_16_NSPI1_SCS5 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_19_16_UART2_RXD (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_19_16_I2C1_SCL (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_19_16_GPIO1_3 (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_15_12 (0x0000F000u)
#define SYSCFG_PINMUX4_PINMUX4_15_12_SHIFT (0x0000000Cu)
/*----PINMUX4_15_12 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_15_12_NSPI1_SCS6 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_15_12_I2C0_SDA (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_15_12_TM64P3_OUT12 (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_15_12_GPIO1_4 (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_11_8 (0x00000F00u)
#define SYSCFG_PINMUX4_PINMUX4_11_8_SHIFT (0x00000008u)
/*----PINMUX4_11_8 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_11_8_NSPI1_SCS7 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_11_8_I2C0_SCL (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_11_8_TM64P2_OUT12 (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_11_8_GPIO1_5 (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_7_4 (0x000000F0u)
#define SYSCFG_PINMUX4_PINMUX4_7_4_SHIFT (0x00000004u)
/*----PINMUX4_7_4 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_7_4_NSPI0_SCS0 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_7_4_TM64P1_OUT12 (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_7_4_GPIO1_6 (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_7_4_MDIO_D (0x00000008u)

#define SYSCFG_PINMUX4_PINMUX4_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX4_PINMUX4_3_0_SHIFT (0x00000000u)
/*----PINMUX4_3_0 Tokens----*/
#define SYSCFG_PINMUX4_PINMUX4_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX4_PINMUX4_3_0_NSPI0_SCS1 (0x00000001u)
#define SYSCFG_PINMUX4_PINMUX4_3_0_TM64P0_OUT12 (0x00000002u)
#define SYSCFG_PINMUX4_PINMUX4_3_0_GPIO1_7 (0x00000004u)
#define SYSCFG_PINMUX4_PINMUX4_3_0_MDIO_CLK (0x00000008u)


/* PINMUX5 */

#define SYSCFG_PINMUX5_PINMUX5_31_28 (0xF0000000u)
#define SYSCFG_PINMUX5_PINMUX5_31_28_SHIFT (0x0000001Cu)
/*----PINMUX5_31_28 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_31_28_EMA_BA0 (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_31_28_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_31_28_GPIO2_8 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_27_24 (0x0F000000u)
#define SYSCFG_PINMUX5_PINMUX5_27_24_SHIFT (0x00000018u)
/*----PINMUX5_27_24 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_27_24_EMA_BA1 (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_27_24_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_27_24_GPIO2_9 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_23_20 (0x00F00000u)
#define SYSCFG_PINMUX5_PINMUX5_23_20_SHIFT (0x00000014u)
/*----PINMUX5_23_20 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_23_20_SPI1_SIMO0 (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_23_20_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_23_20_GPIO2_10 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_19_16 (0x000F0000u)
#define SYSCFG_PINMUX5_PINMUX5_19_16_SHIFT (0x00000010u)
/*----PINMUX5_19_16 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_19_16_SPI1_SOMI0 (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_19_16_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_19_16_GPIO2_11 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_15_12 (0x0000F000u)
#define SYSCFG_PINMUX5_PINMUX5_15_12_SHIFT (0x0000000Cu)
/*----PINMUX5_15_12 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_15_12_NSPI1_ENA (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_15_12_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_15_12_GPIO2_12 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_11_8 (0x00000F00u)
#define SYSCFG_PINMUX5_PINMUX5_11_8_SHIFT (0x00000008u)
/*----PINMUX5_11_8 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_11_8_SPI1_CLK (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_11_8_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_11_8_GPIO2_13 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_7_4 (0x000000F0u)
#define SYSCFG_PINMUX5_PINMUX5_7_4_SHIFT (0x00000004u)
/*----PINMUX5_7_4 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_7_4_NSPI1_SCS0 (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_7_4_EPWM1B (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_7_4_PRU0_R30_7 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_7_4_GPIO2_14 (0x00000008u)

#define SYSCFG_PINMUX5_PINMUX5_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX5_PINMUX5_3_0_SHIFT (0x00000000u)
/*----PINMUX5_3_0 Tokens----*/
#define SYSCFG_PINMUX5_PINMUX5_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX5_PINMUX5_3_0_NSPI1_SCS1 (0x00000001u)
#define SYSCFG_PINMUX5_PINMUX5_3_0_EPWM1A (0x00000002u)
#define SYSCFG_PINMUX5_PINMUX5_3_0_PRU0_R30_8 (0x00000004u)
#define SYSCFG_PINMUX5_PINMUX5_3_0_GPIO2_15 (0x00000008u)


/* PINMUX6 */

#define SYSCFG_PINMUX6_PINMUX6_31_28 (0xF0000000u)
#define SYSCFG_PINMUX6_PINMUX6_31_28_SHIFT (0x0000001Cu)
/*----PINMUX6_31_28 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_31_28_NEMA_CS0 (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_31_28_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_31_28_GPIO2_0 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_27_24 (0x0F000000u)
#define SYSCFG_PINMUX6_PINMUX6_27_24_SHIFT (0x00000018u)
/*----PINMUX6_27_24 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_27_24_EMA_WAIT1 (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_27_24_PRU0_R30_1 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_27_24_GPIO2_1 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_23_20 (0x00F00000u)
#define SYSCFG_PINMUX6_PINMUX6_23_20_SHIFT (0x00000014u)
/*----PINMUX6_23_20 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_23_20_NEMA_WE_DQM1 (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_23_20_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_23_20_GPIO2_2 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_19_16 (0x000F0000u)
#define SYSCFG_PINMUX6_PINMUX6_19_16_SHIFT (0x00000010u)
/*----PINMUX6_19_16 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_19_16_NEMA_WE_DQM0 (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_19_16_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_19_16_GPIO2_3 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_15_12 (0x0000F000u)
#define SYSCFG_PINMUX6_PINMUX6_15_12_SHIFT (0x0000000Cu)
/*----PINMUX6_15_12 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_15_12_NEMA_CAS (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_15_12_PRU0_R30_2 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_15_12_GPIO2_4 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_11_8 (0x00000F00u)
#define SYSCFG_PINMUX6_PINMUX6_11_8_SHIFT (0x00000008u)
/*----PINMUX6_11_8 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_11_8_NEMA_RAS (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_11_8_PRU0_R30_3 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_11_8_GPIO2_5 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_7_4 (0x000000F0u)
#define SYSCFG_PINMUX6_PINMUX6_7_4_SHIFT (0x00000004u)
/*----PINMUX6_7_4 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_7_4_EMA_SDCKE (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_7_4_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_7_4_PRU0_R30_4 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_7_4_GPIO2_6 (0x00000008u)

#define SYSCFG_PINMUX6_PINMUX6_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX6_PINMUX6_3_0_SHIFT (0x00000000u)
/*----PINMUX6_3_0 Tokens----*/
#define SYSCFG_PINMUX6_PINMUX6_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX6_PINMUX6_3_0_EMA_CLK (0x00000001u)
#define SYSCFG_PINMUX6_PINMUX6_3_0_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX6_PINMUX6_3_0_PRU0_R30_5 (0x00000004u)
#define SYSCFG_PINMUX6_PINMUX6_3_0_GPIO2_7 (0x00000008u)


/* PINMUX7 */

#define SYSCFG_PINMUX7_PINMUX7_31_28 (0xF0000000u)
#define SYSCFG_PINMUX7_PINMUX7_31_28_SHIFT (0x0000001Cu)
/*----PINMUX7_31_28 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_31_28_EMA_WAIT0 (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_31_28_PRU0_R30_0 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_31_28_GPIO3_8 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_27_24 (0x0F000000u)
#define SYSCFG_PINMUX7_PINMUX7_27_24_SHIFT (0x00000018u)
/*----PINMUX7_27_24 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_27_24_NEMA_RNW (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_27_24_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_27_24_GPIO3_9 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_23_20 (0x00F00000u)
#define SYSCFG_PINMUX7_PINMUX7_23_20_SHIFT (0x00000014u)
/*----PINMUX7_23_20 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_23_20_NEMA_OE (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_23_20_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_23_20_GPIO3_10 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_19_16 (0x000F0000u)
#define SYSCFG_PINMUX7_PINMUX7_19_16_SHIFT (0x00000010u)
/*----PINMUX7_19_16 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_19_16_NEMA_WE (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_19_16_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_19_16_GPIO3_11 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_15_12 (0x0000F000u)
#define SYSCFG_PINMUX7_PINMUX7_15_12_SHIFT (0x0000000Cu)
/*----PINMUX7_15_12 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_15_12_NEMA_CS5 (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_15_12_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_15_12_GPIO3_12 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_11_8 (0x00000F00u)
#define SYSCFG_PINMUX7_PINMUX7_11_8_SHIFT (0x00000008u)
/*----PINMUX7_11_8 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_11_8_NEMA_CS4 (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_11_8_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_11_8_GPIO3_13 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_7_4 (0x000000F0u)
#define SYSCFG_PINMUX7_PINMUX7_7_4_SHIFT (0x00000004u)
/*----PINMUX7_7_4 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_7_4_NEMA_CS3 (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_7_4_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_7_4_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_7_4_GPIO3_14 (0x00000008u)

#define SYSCFG_PINMUX7_PINMUX7_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX7_PINMUX7_3_0_SHIFT (0x00000000u)
/*----PINMUX7_3_0 Tokens----*/
#define SYSCFG_PINMUX7_PINMUX7_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX7_PINMUX7_3_0_NEMA_CS2 (0x00000001u)
#define SYSCFG_PINMUX7_PINMUX7_3_0_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX7_PINMUX7_3_0_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX7_PINMUX7_3_0_GPIO3_15 (0x00000008u)


/* PINMUX8 */

#define SYSCFG_PINMUX8_PINMUX8_31_28 (0xF0000000u)
#define SYSCFG_PINMUX8_PINMUX8_31_28_SHIFT (0x0000001Cu)
/*----PINMUX8_31_28 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_31_28_EMA_D8 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_31_28_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_31_28_GPIO3_0 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_27_24 (0x0F000000u)
#define SYSCFG_PINMUX8_PINMUX8_27_24_SHIFT (0x00000018u)
/*----PINMUX8_27_24 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_27_24_EMA_D9 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_27_24_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_27_24_GPIO3_1 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_23_20 (0x00F00000u)
#define SYSCFG_PINMUX8_PINMUX8_23_20_SHIFT (0x00000014u)
/*----PINMUX8_23_20 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_23_20_EMA_D10 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_23_20_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_23_20_GPIO3_2 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_19_16 (0x000F0000u)
#define SYSCFG_PINMUX8_PINMUX8_19_16_SHIFT (0x00000010u)
/*----PINMUX8_19_16 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_19_16_EMA_D11 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_19_16_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_19_16_GPIO3_3 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_15_12 (0x0000F000u)
#define SYSCFG_PINMUX8_PINMUX8_15_12_SHIFT (0x0000000Cu)
/*----PINMUX8_15_12 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_15_12_EMA_D12 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_15_12_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_15_12_GPIO3_4 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_11_8 (0x00000F00u)
#define SYSCFG_PINMUX8_PINMUX8_11_8_SHIFT (0x00000008u)
/*----PINMUX8_11_8 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_11_8_EMA_D13 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_11_8_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_11_8_GPIO3_5 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_7_4 (0x000000F0u)
#define SYSCFG_PINMUX8_PINMUX8_7_4_SHIFT (0x00000004u)
/*----PINMUX8_7_4 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_7_4_EMA_D14 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_7_4_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_7_4_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_7_4_GPIO3_6 (0x00000008u)

#define SYSCFG_PINMUX8_PINMUX8_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX8_PINMUX8_3_0_SHIFT (0x00000000u)
/*----PINMUX8_3_0 Tokens----*/
#define SYSCFG_PINMUX8_PINMUX8_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX8_PINMUX8_3_0_EMA_D15 (0x00000001u)
#define SYSCFG_PINMUX8_PINMUX8_3_0_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX8_PINMUX8_3_0_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX8_PINMUX8_3_0_GPIO3_7 (0x00000008u)


/* PINMUX9 */

#define SYSCFG_PINMUX9_PINMUX9_31_28 (0xF0000000u)
#define SYSCFG_PINMUX9_PINMUX9_31_28_SHIFT (0x0000001Cu)
/*----PINMUX9_31_28 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_31_28_EMA_D0 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_31_28_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_31_28_GPIO4_8 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_27_24 (0x0F000000u)
#define SYSCFG_PINMUX9_PINMUX9_27_24_SHIFT (0x00000018u)
/*----PINMUX9_27_24 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_27_24_EMA_D1 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_27_24_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_27_24_GPIO4_9 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_23_20 (0x00F00000u)
#define SYSCFG_PINMUX9_PINMUX9_23_20_SHIFT (0x00000014u)
/*----PINMUX9_23_20 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_23_20_EMA_D2 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_23_20_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_23_20_GPIO4_10 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_19_16 (0x000F0000u)
#define SYSCFG_PINMUX9_PINMUX9_19_16_SHIFT (0x00000010u)
/*----PINMUX9_19_16 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_19_16_EMA_D3 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_19_16_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_19_16_GPIO4_11 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_15_12 (0x0000F000u)
#define SYSCFG_PINMUX9_PINMUX9_15_12_SHIFT (0x0000000Cu)
/*----PINMUX9_15_12 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_15_12_EMA_D4 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_15_12_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_15_12_GPIO4_12 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_11_8 (0x00000F00u)
#define SYSCFG_PINMUX9_PINMUX9_11_8_SHIFT (0x00000008u)
/*----PINMUX9_11_8 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_11_8_EMA_D5 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_11_8_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_11_8_GPIO4_13 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_7_4 (0x000000F0u)
#define SYSCFG_PINMUX9_PINMUX9_7_4_SHIFT (0x00000004u)
/*----PINMUX9_7_4 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_7_4_EMA_D6 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_7_4_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_7_4_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_7_4_GPIO4_14 (0x00000008u)

#define SYSCFG_PINMUX9_PINMUX9_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX9_PINMUX9_3_0_SHIFT (0x00000000u)
/*----PINMUX9_3_0 Tokens----*/
#define SYSCFG_PINMUX9_PINMUX9_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX9_PINMUX9_3_0_EMA_D7 (0x00000001u)
#define SYSCFG_PINMUX9_PINMUX9_3_0_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX9_PINMUX9_3_0_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX9_PINMUX9_3_0_GPIO4_15 (0x00000008u)


/* PINMUX10 */

#define SYSCFG_PINMUX10_PINMUX10_31_28 (0xF0000000u)
#define SYSCFG_PINMUX10_PINMUX10_31_28_SHIFT (0x0000001Cu)
/*----PINMUX10_31_28 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_31_28_EMA_A16 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_31_28_MMCSD0_DAT5 (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_31_28_PRU1_R30_24 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_31_28_GPIO4_0 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_27_24 (0x0F000000u)
#define SYSCFG_PINMUX10_PINMUX10_27_24_SHIFT (0x00000018u)
/*----PINMUX10_27_24 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_27_24_EMA_A17 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_27_24_MMCSD0_DAT4 (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_27_24_PRU1_R30_25 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_27_24_GPIO4_1 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_23_20 (0x00F00000u)
#define SYSCFG_PINMUX10_PINMUX10_23_20_SHIFT (0x00000014u)
/*----PINMUX10_23_20 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_23_20_EMA_A18 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_23_20_MMCSD0_DAT3 (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_23_20_PRU1_R30_26 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_23_20_GPIO4_2 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_19_16 (0x000F0000u)
#define SYSCFG_PINMUX10_PINMUX10_19_16_SHIFT (0x00000010u)
/*----PINMUX10_19_16 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_19_16_EMA_A19 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_19_16_MMCSD0_DAT2 (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_19_16_PRU1_R30_27 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_19_16_GPIO4_3 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_15_12 (0x0000F000u)
#define SYSCFG_PINMUX10_PINMUX10_15_12_SHIFT (0x0000000Cu)
/*----PINMUX10_15_12 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_15_12_EMA_A20 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_15_12_MMCSD0_DAT1 (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_15_12_PRU1_R30_28 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_15_12_GPIO4_4 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_11_8 (0x00000F00u)
#define SYSCFG_PINMUX10_PINMUX10_11_8_SHIFT (0x00000008u)
/*----PINMUX10_11_8 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_11_8_EMA_A21 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_11_8_MMCSD0_DAT0 (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_11_8_PRU1_R30_29 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_11_8_GPIO4_5 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_7_4 (0x000000F0u)
#define SYSCFG_PINMUX10_PINMUX10_7_4_SHIFT (0x00000004u)
/*----PINMUX10_7_4 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_7_4_EMA_A22 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_7_4_MMCSD0_CMD (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_7_4_PRU1_R30_30 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_7_4_GPIO4_6 (0x00000008u)

#define SYSCFG_PINMUX10_PINMUX10_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX10_PINMUX10_3_0_SHIFT (0x00000000u)
/*----PINMUX10_3_0 Tokens----*/
#define SYSCFG_PINMUX10_PINMUX10_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX10_PINMUX10_3_0_EMA_A23 (0x00000001u)
#define SYSCFG_PINMUX10_PINMUX10_3_0_MMCSD0_CLK (0x00000002u)
#define SYSCFG_PINMUX10_PINMUX10_3_0_PRU1_R30_31 (0x00000004u)
#define SYSCFG_PINMUX10_PINMUX10_3_0_GPIO4_7 (0x00000008u)


/* PINMUX11 */

#define SYSCFG_PINMUX11_PINMUX11_31_28 (0xF0000000u)
#define SYSCFG_PINMUX11_PINMUX11_31_28_SHIFT (0x0000001Cu)
/*----PINMUX11_31_28 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_31_28_EMA_A8 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_31_28_PRU1_R30_16 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_31_28_GPIO5_8 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_27_24 (0x0F000000u)
#define SYSCFG_PINMUX11_PINMUX11_27_24_SHIFT (0x00000018u)
/*----PINMUX11_27_24 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_27_24_EMA_A9 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_27_24_PRU1_R30_17 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_27_24_GPIO5_9 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_23_20 (0x00F00000u)
#define SYSCFG_PINMUX11_PINMUX11_23_20_SHIFT (0x00000014u)
/*----PINMUX11_23_20 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_23_20_EMA_A10 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_23_20_PRU1_R30_18 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_23_20_GPIO5_10 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_19_16 (0x000F0000u)
#define SYSCFG_PINMUX11_PINMUX11_19_16_SHIFT (0x00000010u)
/*----PINMUX11_19_16 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_19_16_EMA_A11 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_19_16_PRU1_R30_19 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_19_16_GPIO5_11 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_15_12 (0x0000F000u)
#define SYSCFG_PINMUX11_PINMUX11_15_12_SHIFT (0x0000000Cu)
/*----PINMUX11_15_12 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_15_12_EMA_A12 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_15_12_PRU1_R30_20 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_15_12_GPIO5_12 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_11_8 (0x00000F00u)
#define SYSCFG_PINMUX11_PINMUX11_11_8_SHIFT (0x00000008u)
/*----PINMUX11_11_8 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_11_8_EMA_A13 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_11_8_PRU0_R30_21 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_11_8_PRU1_R30_21 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_11_8_GPIO5_13 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_7_4 (0x000000F0u)
#define SYSCFG_PINMUX11_PINMUX11_7_4_SHIFT (0x00000004u)
/*----PINMUX11_7_4 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_7_4_EMA_A14 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_7_4_MMCSD0_DAT7 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_7_4_PRU1_R30_22 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_7_4_GPIO5_14 (0x00000008u)

#define SYSCFG_PINMUX11_PINMUX11_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX11_PINMUX11_3_0_SHIFT (0x00000000u)
/*----PINMUX11_3_0 Tokens----*/
#define SYSCFG_PINMUX11_PINMUX11_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX11_PINMUX11_3_0_EMA_A15 (0x00000001u)
#define SYSCFG_PINMUX11_PINMUX11_3_0_MMCSD0_DAT6 (0x00000002u)
#define SYSCFG_PINMUX11_PINMUX11_3_0_PRU1_R30_23 (0x00000004u)
#define SYSCFG_PINMUX11_PINMUX11_3_0_GPIO5_15 (0x00000008u)


/* PINMUX12 */

#define SYSCFG_PINMUX12_PINMUX12_31_28 (0xF0000000u)
#define SYSCFG_PINMUX12_PINMUX12_31_28_SHIFT (0x0000001Cu)
/*----PINMUX12_31_28 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_31_28_EMA_A0 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_31_28_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_31_28_GPIO5_0 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_27_24 (0x0F000000u)
#define SYSCFG_PINMUX12_PINMUX12_27_24_SHIFT (0x00000018u)
/*----PINMUX12_27_24 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_27_24_EMA_A1 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_27_24_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_27_24_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_27_24_GPIO5_1 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_23_20 (0x00F00000u)
#define SYSCFG_PINMUX12_PINMUX12_23_20_SHIFT (0x00000014u)
/*----PINMUX12_23_20 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_23_20_EMA_A2 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_23_20_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_23_20_GPIO5_2 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_19_16 (0x000F0000u)
#define SYSCFG_PINMUX12_PINMUX12_19_16_SHIFT (0x00000010u)
/*----PINMUX12_19_16 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_19_16_EMA_A3 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_19_16_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_19_16_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_19_16_GPIO5_3 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_15_12 (0x0000F000u)
#define SYSCFG_PINMUX12_PINMUX12_15_12_SHIFT (0x0000000Cu)
/*----PINMUX12_15_12 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_15_12_EMA_A4 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_15_12_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_15_12_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_15_12_GPIO5_4 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_11_8 (0x00000F00u)
#define SYSCFG_PINMUX12_PINMUX12_11_8_SHIFT (0x00000008u)
/*----PINMUX12_11_8 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_11_8_EMA_A5 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_11_8_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_11_8_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_11_8_GPIO5_5 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_7_4 (0x000000F0u)
#define SYSCFG_PINMUX12_PINMUX12_7_4_SHIFT (0x00000004u)
/*----PINMUX12_7_4 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_7_4_EMA_A6 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_7_4_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_7_4_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_7_4_GPIO5_6 (0x00000008u)

#define SYSCFG_PINMUX12_PINMUX12_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX12_PINMUX12_3_0_SHIFT (0x00000000u)
/*----PINMUX12_3_0 Tokens----*/
#define SYSCFG_PINMUX12_PINMUX12_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX12_PINMUX12_3_0_EMA_A7 (0x00000001u)
#define SYSCFG_PINMUX12_PINMUX12_3_0_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX12_PINMUX12_3_0_PRU1_R30_15 (0x00000004u)
#define SYSCFG_PINMUX12_PINMUX12_3_0_GPIO5_7 (0x00000008u)


/* PINMUX13 */

#define SYSCFG_PINMUX13_PINMUX13_31_28 (0xF0000000u)
#define SYSCFG_PINMUX13_PINMUX13_31_28_SHIFT (0x0000001Cu)
/*----PINMUX13_31_28 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_31_28_PRU0_R30_26 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_31_28_UHPI_HRNW (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_31_28_CH1_WAIT (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_31_28_GPIO6_8 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_27_24 (0x0F000000u)
#define SYSCFG_PINMUX13_PINMUX13_27_24_SHIFT (0x00000018u)
/*----PINMUX13_27_24 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_27_24_PRU0_R30_27 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_27_24_UHPI_HHWIL (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_27_24_GPIO6_9 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_23_20 (0x00F00000u)
#define SYSCFG_PINMUX13_PINMUX13_23_20_SHIFT (0x00000014u)
/*----PINMUX13_23_20 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_23_20_PRU0_R30_28 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_23_20_UHPI_HCNTL1 (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_23_20_CH1_START (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_23_20_GPIO6_10 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_19_16 (0x000F0000u)
#define SYSCFG_PINMUX13_PINMUX13_19_16_SHIFT (0x00000010u)
/*----PINMUX13_19_16 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_19_16_PRU0_R30_29 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_19_16_UHPI_HCNTL0 (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_19_16_CH1_CLK (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_19_16_GPIO6_11 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_15_12 (0x0000F000u)
#define SYSCFG_PINMUX13_PINMUX13_15_12_SHIFT (0x0000000Cu)
/*----PINMUX13_15_12 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_15_12_PRU0_R30_30 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_15_12_NUHPI_HINT (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_15_12_PRU1_R30_11 (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_15_12_GPIO6_12 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_11_8 (0x00000F00u)
#define SYSCFG_PINMUX13_PINMUX13_11_8_SHIFT (0x00000008u)
/*----PINMUX13_11_8 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_11_8_PRU0_R30_31 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_11_8_NUHPI_HRDY (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_11_8_PRU1_R30_12 (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_11_8_GPIO6_13 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_7_4 (0x000000F0u)
#define SYSCFG_PINMUX13_PINMUX13_7_4_SHIFT (0x00000004u)
/*----PINMUX13_7_4 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_7_4_OBSCLK0 (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_7_4_NUHPI_HDS2 (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_7_4_PRU1_R30_13 (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_7_4_GPIO6_14 (0x00000008u)

#define SYSCFG_PINMUX13_PINMUX13_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX13_PINMUX13_3_0_SHIFT (0x00000000u)
/*----PINMUX13_3_0 Tokens----*/
#define SYSCFG_PINMUX13_PINMUX13_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX13_PINMUX13_3_0_NRESETOUT (0x00000001u)
#define SYSCFG_PINMUX13_PINMUX13_3_0_NUHPI_HAS (0x00000002u)
#define SYSCFG_PINMUX13_PINMUX13_3_0_PRU1_R30_14 (0x00000004u)
#define SYSCFG_PINMUX13_PINMUX13_3_0_GPIO6_15 (0x00000008u)


/* PINMUX14 */

#define SYSCFG_PINMUX14_PINMUX14_31_28 (0xF0000000u)
#define SYSCFG_PINMUX14_PINMUX14_31_28_SHIFT (0x0000001Cu)
/*----PINMUX14_31_28 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_31_28_DIN2 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_31_28_UHPI_HD10 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_31_28_UPP_D10 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_31_28_RMII_RXER (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_27_24 (0x0F000000u)
#define SYSCFG_PINMUX14_PINMUX14_27_24_SHIFT (0x00000018u)
/*----PINMUX14_27_24 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_27_24_DIN3 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_27_24_UHPI_HD11 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_27_24_UPP_D11 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_27_24_RMII_RXD0 (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_23_20 (0x00F00000u)
#define SYSCFG_PINMUX14_PINMUX14_23_20_SHIFT (0x00000014u)
/*----PINMUX14_23_20 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_23_20_DIN4 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_23_20_UHPI_HD12 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_23_20_UPP_D12 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_23_20_RMII_RXD1 (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_19_16 (0x000F0000u)
#define SYSCFG_PINMUX14_PINMUX14_19_16_SHIFT (0x00000010u)
/*----PINMUX14_19_16 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_19_16_DIN5 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_19_16_UHPI_HD13 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_19_16_UPP_D13 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_19_16_RMII_TXEN (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_15_12 (0x0000F000u)
#define SYSCFG_PINMUX14_PINMUX14_15_12_SHIFT (0x0000000Cu)
/*----PINMUX14_15_12 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_15_12_DIN6 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_15_12_UHPI_HD14 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_15_12_UPP_D14 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_15_12_RMII_TXD0 (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_11_8 (0x00000F00u)
#define SYSCFG_PINMUX14_PINMUX14_11_8_SHIFT (0x00000008u)
/*----PINMUX14_11_8 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_11_8_DIN7 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_11_8_UHPI_HD15 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_11_8_UPP_D15 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_11_8_RMII_TXD1 (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_7_4 (0x000000F0u)
#define SYSCFG_PINMUX14_PINMUX14_7_4_SHIFT (0x00000004u)
/*----PINMUX14_7_4 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_7_4_CLKIN1 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_7_4_NUHPI_HDS1 (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_7_4_PRU1_R30_9 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_7_4_GPIO6_6 (0x00000008u)

#define SYSCFG_PINMUX14_PINMUX14_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX14_PINMUX14_3_0_SHIFT (0x00000000u)
/*----PINMUX14_3_0 Tokens----*/
#define SYSCFG_PINMUX14_PINMUX14_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX14_PINMUX14_3_0_CLKIN0 (0x00000001u)
#define SYSCFG_PINMUX14_PINMUX14_3_0_NUHPI_HCS (0x00000002u)
#define SYSCFG_PINMUX14_PINMUX14_3_0_PRU1_R30_10 (0x00000004u)
#define SYSCFG_PINMUX14_PINMUX14_3_0_GPIO6_7 (0x00000008u)


/* PINMUX15 */

#define SYSCFG_PINMUX15_PINMUX15_31_28 (0xF0000000u)
#define SYSCFG_PINMUX15_PINMUX15_31_28_SHIFT (0x0000001Cu)
/*----PINMUX15_31_28 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_31_28_DIN10 (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_31_28_UHPI_HD2 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_31_28_UPP_D2 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_31_28_PRU0_R30_10 (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_27_24 (0x0F000000u)
#define SYSCFG_PINMUX15_PINMUX15_27_24_SHIFT (0x00000018u)
/*----PINMUX15_27_24 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_27_24_DIN11 (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_27_24_UHPI_HD3 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_27_24_UPP_D3 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_27_24_PRU0_R30_11 (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_23_20 (0x00F00000u)
#define SYSCFG_PINMUX15_PINMUX15_23_20_SHIFT (0x00000014u)
/*----PINMUX15_23_20 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_23_20_DIN12 (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_23_20_UHPI_HD4 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_23_20_UPP_D4 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_23_20_PRU0_R30_12 (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_19_16 (0x000F0000u)
#define SYSCFG_PINMUX15_PINMUX15_19_16_SHIFT (0x00000010u)
/*----PINMUX15_19_16 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_19_16_DIN13_FIELD (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_19_16_UHPI_HD5 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_19_16_UPP_D5 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_19_16_PRU0_R30_13 (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_15_12 (0x0000F000u)
#define SYSCFG_PINMUX15_PINMUX15_15_12_SHIFT (0x0000000Cu)
/*----PINMUX15_15_12 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_15_12_DIN14_HSYNC (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_15_12_UHPI_HD6 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_15_12_UPP_D6 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_15_12_PRU0_R30_14 (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_11_8 (0x00000F00u)
#define SYSCFG_PINMUX15_PINMUX15_11_8_SHIFT (0x00000008u)
/*----PINMUX15_11_8 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_11_8_DIN15_VSYNC (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_11_8_UHPI_HD7 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_11_8_UPP_D7 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_11_8_PRU0_R30_15 (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_7_4 (0x000000F0u)
#define SYSCFG_PINMUX15_PINMUX15_7_4_SHIFT (0x00000004u)
/*----PINMUX15_7_4 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_7_4_DIN0 (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_7_4_UHPI_HD8 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_7_4_UPP_D8 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_7_4_RMII_CRS_DV (0x00000008u)

#define SYSCFG_PINMUX15_PINMUX15_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX15_PINMUX15_3_0_SHIFT (0x00000000u)
/*----PINMUX15_3_0 Tokens----*/
#define SYSCFG_PINMUX15_PINMUX15_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX15_PINMUX15_3_0_DIN1 (0x00000001u)
#define SYSCFG_PINMUX15_PINMUX15_3_0_UHPI_HD9 (0x00000002u)
#define SYSCFG_PINMUX15_PINMUX15_3_0_UPP_D9 (0x00000004u)
#define SYSCFG_PINMUX15_PINMUX15_3_0_RMII_MHZ_50_CLK (0x00000008u)


/* PINMUX16 */

#define SYSCFG_PINMUX16_PINMUX16_31_28 (0xF0000000u)
#define SYSCFG_PINMUX16_PINMUX16_31_28_SHIFT (0x0000001Cu)
/*----PINMUX16_31_28 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_31_28_DOUT2 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_31_28_LCD_D2 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_31_28_UPP_XD10 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_31_28_GPIO7_10 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_27_24 (0x0F000000u)
#define SYSCFG_PINMUX16_PINMUX16_27_24_SHIFT (0x00000018u)
/*----PINMUX16_27_24 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_27_24_DOUT3 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_27_24_LCD_D3 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_27_24_UPP_XD11 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_27_24_GPIO7_11 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_23_20 (0x00F00000u)
#define SYSCFG_PINMUX16_PINMUX16_23_20_SHIFT (0x00000014u)
/*----PINMUX16_23_20 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_23_20_DOUT4 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_23_20_LCD_D4 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_23_20_UPP_XD12 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_23_20_GPIO7_12 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_19_16 (0x000F0000u)
#define SYSCFG_PINMUX16_PINMUX16_19_16_SHIFT (0x00000010u)
/*----PINMUX16_19_16 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_19_16_DOUT5 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_19_16_LCD_D5 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_19_16_UPP_XD13 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_19_16_GPIO7_13 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_15_12 (0x0000F000u)
#define SYSCFG_PINMUX16_PINMUX16_15_12_SHIFT (0x0000000Cu)
/*----PINMUX16_15_12 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_15_12_DOUT6 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_15_12_LCD_D6 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_15_12_UPP_XD14 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_15_12_GPIO7_14 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_11_8 (0x00000F00u)
#define SYSCFG_PINMUX16_PINMUX16_11_8_SHIFT (0x00000008u)
/*----PINMUX16_11_8 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_11_8_DOUT7 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_11_8_LCD_D7 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_11_8_UPP_XD15 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_11_8_GPIO7_15 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_7_4 (0x000000F0u)
#define SYSCFG_PINMUX16_PINMUX16_7_4_SHIFT (0x00000004u)
/*----PINMUX16_7_4 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_7_4_DIN8 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_7_4_UHPI_HD0 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_7_4_UPP_D0 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_7_4_GPIO6_5 (0x00000008u)

#define SYSCFG_PINMUX16_PINMUX16_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX16_PINMUX16_3_0_SHIFT (0x00000000u)
/*----PINMUX16_3_0 Tokens----*/
#define SYSCFG_PINMUX16_PINMUX16_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX16_PINMUX16_3_0_DIN9 (0x00000001u)
#define SYSCFG_PINMUX16_PINMUX16_3_0_UHPI_HD1 (0x00000002u)
#define SYSCFG_PINMUX16_PINMUX16_3_0_UPP_D1 (0x00000004u)
#define SYSCFG_PINMUX16_PINMUX16_3_0_PRU0_R30_9 (0x00000008u)


/* PINMUX17 */

#define SYSCFG_PINMUX17_PINMUX17_31_28 (0xF0000000u)
#define SYSCFG_PINMUX17_PINMUX17_31_28_SHIFT (0x0000001Cu)
/*----PINMUX17_31_28 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_31_28_DOUT10 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_31_28_LCD_D10 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_31_28_UPP_XD2 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_31_28_GPIO7_2 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_27_24 (0x0F000000u)
#define SYSCFG_PINMUX17_PINMUX17_27_24_SHIFT (0x00000018u)
/*----PINMUX17_27_24 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_27_24_DOUT11 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_27_24_LCD_D11 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_27_24_UPP_XD3 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_27_24_GPIO7_3 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_23_20 (0x00F00000u)
#define SYSCFG_PINMUX17_PINMUX17_23_20_SHIFT (0x00000014u)
/*----PINMUX17_23_20 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_23_20_DOUT12 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_23_20_LCD_D12 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_23_20_UPP_XD4 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_23_20_GPIO7_4 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_19_16 (0x000F0000u)
#define SYSCFG_PINMUX17_PINMUX17_19_16_SHIFT (0x00000010u)
/*----PINMUX17_19_16 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_19_16_DOUT13 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_19_16_LCD_D13 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_19_16_UPP_XD5 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_19_16_GPIO7_5 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_15_12 (0x0000F000u)
#define SYSCFG_PINMUX17_PINMUX17_15_12_SHIFT (0x0000000Cu)
/*----PINMUX17_15_12 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_15_12_DOUT14 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_15_12_LCD_D14 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_15_12_UPP_XD6 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_15_12_GPIO7_6 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_11_8 (0x00000F00u)
#define SYSCFG_PINMUX17_PINMUX17_11_8_SHIFT (0x00000008u)
/*----PINMUX17_11_8 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_11_8_DOUT15 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_11_8_LCD_D15 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_11_8_UPP_XD7 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_11_8_GPIO7_7 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_7_4 (0x000000F0u)
#define SYSCFG_PINMUX17_PINMUX17_7_4_SHIFT (0x00000004u)
/*----PINMUX17_7_4 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_7_4_DOUT0 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_7_4_LCD_D0 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_7_4_UPP_XD8 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_7_4_GPIO7_8 (0x00000008u)

#define SYSCFG_PINMUX17_PINMUX17_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX17_PINMUX17_3_0_SHIFT (0x00000000u)
/*----PINMUX17_3_0 Tokens----*/
#define SYSCFG_PINMUX17_PINMUX17_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX17_PINMUX17_3_0_DOUT1 (0x00000001u)
#define SYSCFG_PINMUX17_PINMUX17_3_0_LCD_D1 (0x00000002u)
#define SYSCFG_PINMUX17_PINMUX17_3_0_UPP_XD9 (0x00000004u)
#define SYSCFG_PINMUX17_PINMUX17_3_0_GPIO7_9 (0x00000008u)


/* PINMUX18 */

#define SYSCFG_PINMUX18_PINMUX18_31_28 (0xF0000000u)
#define SYSCFG_PINMUX18_PINMUX18_31_28_SHIFT (0x0000001Cu)
/*----PINMUX18_31_28 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_31_28_MMCSD1_DAT6 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_31_28_LCD_MCLK (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_31_28_PRU1_R30_6 (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_31_28_GPIO8_10 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_27_24 (0x0F000000u)
#define SYSCFG_PINMUX18_PINMUX18_27_24_SHIFT (0x00000018u)
/*----PINMUX18_27_24 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_27_24_MMCSD1_DAT7 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_27_24_LCD_PCLK (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_27_24_PRU1_R30_7 (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_27_24_GPIO8_11 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_23_20 (0x00F00000u)
#define SYSCFG_PINMUX18_PINMUX18_23_20_SHIFT (0x00000014u)
/*----PINMUX18_23_20 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_23_20_PRU0_R30_22 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_23_20_PRU1_R30_8 (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_23_20_CH0_WAIT (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_23_20_GPIO8_12 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_19_16 (0x000F0000u)
#define SYSCFG_PINMUX18_PINMUX18_19_16_SHIFT (0x00000010u)
/*----PINMUX18_19_16 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_19_16_PRU0_R30_23 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_19_16_MMCSD1_CMD (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_19_16_GPIO8_13 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_15_12 (0x0000F000u)
#define SYSCFG_PINMUX18_PINMUX18_15_12_SHIFT (0x0000000Cu)
/*----PINMUX18_15_12 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_15_12_PRU0_R30_24 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_15_12_MMCSD1_CLK (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_15_12_CH0_START (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_15_12_GPIO8_14 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_11_8 (0x00000F00u)
#define SYSCFG_PINMUX18_PINMUX18_11_8_SHIFT (0x00000008u)
/*----PINMUX18_11_8 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_11_8_PRU0_R30_25 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_11_8_MMCSD1_DAT0 (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_11_8_CH0_CLK (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_11_8_GPIO8_15 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_7_4 (0x000000F0u)
#define SYSCFG_PINMUX18_PINMUX18_7_4_SHIFT (0x00000004u)
/*----PINMUX18_7_4 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_7_4_DOUT8 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_7_4_LCD_D8 (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_7_4_UPP_XD0 (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_7_4_GPIO7_0 (0x00000008u)

#define SYSCFG_PINMUX18_PINMUX18_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX18_PINMUX18_3_0_SHIFT (0x00000000u)
/*----PINMUX18_3_0 Tokens----*/
#define SYSCFG_PINMUX18_PINMUX18_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX18_PINMUX18_3_0_DOUT9 (0x00000001u)
#define SYSCFG_PINMUX18_PINMUX18_3_0_LCD_D9 (0x00000002u)
#define SYSCFG_PINMUX18_PINMUX18_3_0_UPP_XD1 (0x00000004u)
#define SYSCFG_PINMUX18_PINMUX18_3_0_GPIO7_1 (0x00000008u)


/* PINMUX19 */

#define SYSCFG_PINMUX19_PINMUX19_31_28 (0xF0000000u)
#define SYSCFG_PINMUX19_PINMUX19_31_28_SHIFT (0x0000001Cu)
/*----PINMUX19_31_28 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_31_28_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_31_28_RTCK (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_31_28_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_31_28_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_31_28_GPIO8_0 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_27_24 (0x0F000000u)
#define SYSCFG_PINMUX19_PINMUX19_27_24_SHIFT (0x00000018u)
/*----PINMUX19_27_24 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_27_24_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_27_24_RESERVED1 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_27_24_NLCD_AC_ENB_CS (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_27_24_RESERVED4 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_27_24_GPIO6_0 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_23_20 (0x00F00000u)
#define SYSCFG_PINMUX19_PINMUX19_23_20_SHIFT (0x00000014u)
/*----PINMUX19_23_20 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_23_20_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_23_20_CLKO3 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_23_20_RESERVED2 (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_23_20_PRU1_R30_0 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_23_20_GPIO6_1 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_19_16 (0x000F0000u)
#define SYSCFG_PINMUX19_PINMUX19_19_16_SHIFT (0x00000010u)
/*----PINMUX19_19_16 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_19_16_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_19_16_CLKIN3 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_19_16_MMCSD1_DAT1 (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_19_16_PRU1_R30_1 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_19_16_GPIO6_2 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_15_12 (0x0000F000u)
#define SYSCFG_PINMUX19_PINMUX19_15_12_SHIFT (0x0000000Cu)
/*----PINMUX19_15_12 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_15_12_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_15_12_CLKO2 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_15_12_MMCSD1_DAT2 (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_15_12_PRU1_R30_2 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_15_12_GPIO6_3 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_11_8 (0x00000F00u)
#define SYSCFG_PINMUX19_PINMUX19_11_8_SHIFT (0x00000008u)
/*----PINMUX19_11_8 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_11_8_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_11_8_CLKIN2 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_11_8_MMCSD1_DAT3 (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_11_8_PRU1_R30_3 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_11_8_GPIO6_4 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_7_4 (0x000000F0u)
#define SYSCFG_PINMUX19_PINMUX19_7_4_SHIFT (0x00000004u)
/*----PINMUX19_7_4 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_7_4_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_7_4_MMCSD1_DAT4 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_7_4_LCD_VSYNC (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_7_4_PRU1_R30_4 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_7_4_GPIO8_8 (0x00000008u)

#define SYSCFG_PINMUX19_PINMUX19_3_0 (0x0000000Fu)
#define SYSCFG_PINMUX19_PINMUX19_3_0_SHIFT (0x00000000u)
/*----PINMUX19_3_0 Tokens----*/
#define SYSCFG_PINMUX19_PINMUX19_3_0_DEFAULT (0x00000000u)
#define SYSCFG_PINMUX19_PINMUX19_3_0_MMCSD1_DAT5 (0x00000001u)
#define SYSCFG_PINMUX19_PINMUX19_3_0_LCD_HSYNC (0x00000002u)
#define SYSCFG_PINMUX19_PINMUX19_3_0_PRU1_R30_5 (0x00000004u)
#define SYSCFG_PINMUX19_PINMUX19_3_0_GPIO8_9 (0x00000008u)


/* SUSPSRC */


#define SYSCFG_SUSPSRC_TIMER64P_2SRC (0x20000000u)
#define SYSCFG_SUSPSRC_TIMER64P_2SRC_SHIFT (0x0000001Du)

#define SYSCFG_SUSPSRC_TIMER64P_1SRC (0x10000000u)
#define SYSCFG_SUSPSRC_TIMER64P_1SRC_SHIFT (0x0000001Cu)

#define SYSCFG_SUSPSRC_TIMER64P_0SRC (0x08000000u)
#define SYSCFG_SUSPSRC_TIMER64P_0SRC_SHIFT (0x0000001Bu)


#define SYSCFG_SUSPSRC_EPWM1SRC (0x01000000u)
#define SYSCFG_SUSPSRC_EPWM1SRC_SHIFT (0x00000018u)

#define SYSCFG_SUSPSRC_EPWM0SRC (0x00800000u)
#define SYSCFG_SUSPSRC_EPWM0SRC_SHIFT (0x00000017u)

#define SYSCFG_SUSPSRC_SPI1SRC  (0x00400000u)
#define SYSCFG_SUSPSRC_SPI1SRC_SHIFT (0x00000016u)

#define SYSCFG_SUSPSRC_SPI0SRC  (0x00200000u)
#define SYSCFG_SUSPSRC_SPI0SRC_SHIFT (0x00000015u)

#define SYSCFG_SUSPSRC_UART2SRC (0x00100000u)
#define SYSCFG_SUSPSRC_UART2SRC_SHIFT (0x00000014u)

#define SYSCFG_SUSPSRC_UART1SRC (0x00080000u)
#define SYSCFG_SUSPSRC_UART1SRC_SHIFT (0x00000013u)

#define SYSCFG_SUSPSRC_UART0SRC (0x00040000u)
#define SYSCFG_SUSPSRC_UART0SRC_SHIFT (0x00000012u)

#define SYSCFG_SUSPSRC_I2C1SRC  (0x00020000u)
#define SYSCFG_SUSPSRC_I2C1SRC_SHIFT (0x00000011u)

#define SYSCFG_SUSPSRC_I2C0SRC  (0x00010000u)
#define SYSCFG_SUSPSRC_I2C0SRC_SHIFT (0x00000010u)


#define SYSCFG_SUSPSRC_VPIFSRC  (0x00004000u)
#define SYSCFG_SUSPSRC_VPIFSRC_SHIFT (0x0000000Eu)

#define SYSCFG_SUSPSRC_SATASRC  (0x00002000u)
#define SYSCFG_SUSPSRC_SATASRC_SHIFT (0x0000000Du)

#define SYSCFG_SUSPSRC_HPISRC   (0x00001000u)
#define SYSCFG_SUSPSRC_HPISRC_SHIFT  (0x0000000Cu)


#define SYSCFG_SUSPSRC_USB0SRC  (0x00000200u)
#define SYSCFG_SUSPSRC_USB0SRC_SHIFT (0x00000009u)

#define SYSCFG_SUSPSRC_MCBSP1SRC (0x00000100u)
#define SYSCFG_SUSPSRC_MCBSP1SRC_SHIFT (0x00000008u)

#define SYSCFG_SUSPSRC_MCBSP0SRC (0x00000080u)
#define SYSCFG_SUSPSRC_MCBSP0SRC_SHIFT (0x00000007u)

#define SYSCFG_SUSPSRC_PRUSRC   (0x00000040u)
#define SYSCFG_SUSPSRC_PRUSRC_SHIFT  (0x00000006u)

#define SYSCFG_SUSPSRC_EMACSRC  (0x00000020u)
#define SYSCFG_SUSPSRC_EMACSRC_SHIFT (0x00000005u)

#define SYSCFG_SUSPSRC_UPPSRC   (0x00000010u)
#define SYSCFG_SUSPSRC_UPPSRC_SHIFT  (0x00000004u)

#define SYSCFG_SUSPSRC_TIMER64P_3SRC (0x00000008u)
#define SYSCFG_SUSPSRC_TIMER64P_3SRC_SHIFT (0x00000003u)

#define SYSCFG_SUSPSRC_ECAP2SRC (0x00000004u)
#define SYSCFG_SUSPSRC_ECAP2SRC_SHIFT (0x00000002u)

#define SYSCFG_SUSPSRC_ECAP1SRC (0x00000002u)
#define SYSCFG_SUSPSRC_ECAP1SRC_SHIFT (0x00000001u)

#define SYSCFG_SUSPSRC_ECAP0SRC (0x00000001u)
#define SYSCFG_SUSPSRC_ECAP0SRC_SHIFT (0x00000000u)


/* CHIPSIG */


#define SYSCFG_CHIPSIG_CHIPSIG4 (0x00000010u)
#define SYSCFG_CHIPSIG_CHIPSIG4_SHIFT (0x00000004u)

#define SYSCFG_CHIPSIG_CHIPSIG3 (0x00000008u)
#define SYSCFG_CHIPSIG_CHIPSIG3_SHIFT (0x00000003u)

#define SYSCFG_CHIPSIG_CHIPSIG2 (0x00000004u)
#define SYSCFG_CHIPSIG_CHIPSIG2_SHIFT (0x00000002u)

#define SYSCFG_CHIPSIG_CHIPSIG1 (0x00000002u)
#define SYSCFG_CHIPSIG_CHIPSIG1_SHIFT (0x00000001u)

#define SYSCFG_CHIPSIG_CHIPSIG0 (0x00000001u)
#define SYSCFG_CHIPSIG_CHIPSIG0_SHIFT (0x00000000u)


/* CHIPSIG_CLR */


#define SYSCFG_CHIPSIG_CLR_CHIPSIG4 (0x00000010u)
#define SYSCFG_CHIPSIG_CLR_CHIPSIG4_SHIFT (0x00000004u)

#define SYSCFG_CHIPSIG_CLR_CHIPSIG3 (0x00000008u)
#define SYSCFG_CHIPSIG_CLR_CHIPSIG3_SHIFT (0x00000003u)

#define SYSCFG_CHIPSIG_CLR_CHIPSIG2 (0x00000004u)
#define SYSCFG_CHIPSIG_CLR_CHIPSIG2_SHIFT (0x00000002u)

#define SYSCFG_CHIPSIG_CLR_CHIPSIG1 (0x00000002u)
#define SYSCFG_CHIPSIG_CLR_CHIPSIG1_SHIFT (0x00000001u)

#define SYSCFG_CHIPSIG_CLR_CHIPSIG0 (0x00000001u)
#define SYSCFG_CHIPSIG_CLR_CHIPSIG0_SHIFT (0x00000000u)


/* CFGCHIP0 */

#define SYSCFG_CFGCHIP0_ARM_CLK_DIS0 (0x80000000u)
#define SYSCFG_CFGCHIP0_ARM_CLK_DIS0_SHIFT (0x0000001Fu)

#define SYSCFG_CFGCHIP0_ARM_TAP_DIS0 (0x40000000u)
#define SYSCFG_CFGCHIP0_ARM_TAP_DIS0_SHIFT (0x0000001Eu)


#define SYSCFG_CFGCHIP0_PLL_MASTER_LOCK (0x00000010u)
#define SYSCFG_CFGCHIP0_PLL_MASTER_LOCK_SHIFT (0x00000004u)

#define SYSCFG_CFGCHIP0_EDMA30TC1DBS (0x0000000Cu)
#define SYSCFG_CFGCHIP0_EDMA30TC1DBS_SHIFT (0x00000002u)
/*----EDMA30TC1DBS Tokens----*/
#define SYSCFG_CFGCHIP0_EDMA30TC1DBS_16BYTE (0x00000000u)
#define SYSCFG_CFGCHIP0_EDMA30TC1DBS_32BYTE (0x00000001u)
#define SYSCFG_CFGCHIP0_EDMA30TC1DBS_64BYTE (0x00000002u)
#define SYSCFG_CFGCHIP0_EDMA30TC1DBS_RESERVED (0x00000003u)

#define SYSCFG_CFGCHIP0_EDMA30TC0DBS (0x00000003u)
#define SYSCFG_CFGCHIP0_EDMA30TC0DBS_SHIFT (0x00000000u)
/*----EDMA30TC0DBS Tokens----*/
#define SYSCFG_CFGCHIP0_EDMA30TC0DBS_16BYTE (0x00000000u)
#define SYSCFG_CFGCHIP0_EDMA30TC0DBS_32BYTE (0x00000001u)
#define SYSCFG_CFGCHIP0_EDMA30TC0DBS_64BYTE (0x00000002u)
#define SYSCFG_CFGCHIP0_EDMA30TC0DBS_RESERVED (0x00000003u)


/* CFGCHIP1 */

#define SYSCFG_CFGCHIP1_CAP2SRC (0xF8000000u)
#define SYSCFG_CFGCHIP1_CAP2SRC_SHIFT (0x0000001Bu)
/*----CAP2SRC Tokens----*/
#define SYSCFG_CFGCHIP1_CAP2SRC_ECAP2 (0x00000000u)
#define SYSCFG_CFGCHIP1_CAP2SRC_MCASP0_TXDMA (0x00000001u)
#define SYSCFG_CFGCHIP1_CAP2SRC_MCASP0_RXDMA (0x00000002u)
#define SYSCFG_CFGCHIP1_CAP2SRC_MCASP1_TXDMA (0x00000003u)
#define SYSCFG_CFGCHIP1_CAP2SRC_MCASP1_RXDMA (0x00000004u)
#define SYSCFG_CFGCHIP1_CAP2SRC_MCASP2_TXDMA (0x00000005u)
#define SYSCFG_CFGCHIP1_CAP2SRC_MCASP2_RXDMA (0x00000006u)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C0_RXTHPLSEINT (0x00000007u)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C0_RXPLSEINT (0x00000008u)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C0_TXPLSEINT (0x00000009u)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C0_MISCINT (0x0000000au)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C1_RXTHPLSEINT (0x0000000bu)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C1_RXPLSEINT (0x0000000cu)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C1_TXPLSEINT (0x0000000du)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C1_MISCINT (0x0000000eu)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C2_RXTHPLSEINT (0x0000000fu)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C2_RXPLSEINT (0x00000010u)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C2_TXPLSEINT (0x00000011u)
#define SYSCFG_CFGCHIP1_CAP2SRC_EMAC_C2_MISCINT (0x00000012u)

#define SYSCFG_CFGCHIP1_CAP1SRC (0x07C00000u)
#define SYSCFG_CFGCHIP1_CAP1SRC_SHIFT (0x00000016u)
/*----CAP1SRC Tokens----*/
#define SYSCFG_CFGCHIP1_CAP1SRC_ECAP1 (0x00000000u)
#define SYSCFG_CFGCHIP1_CAP1SRC_MCASP0_TXDMA (0x00000001u)
#define SYSCFG_CFGCHIP1_CAP1SRC_MCASP0_RXDMA (0x00000002u)
#define SYSCFG_CFGCHIP1_CAP1SRC_MCASP1_TXDMA (0x00000003u)
#define SYSCFG_CFGCHIP1_CAP1SRC_MCASP1_RXDMA (0x00000004u)
#define SYSCFG_CFGCHIP1_CAP1SRC_MCASP2_TXDMA (0x00000005u)
#define SYSCFG_CFGCHIP1_CAP1SRC_MCASP2_RXDMA (0x00000006u)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C0_RXTHPLSEINT (0x00000007u)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C0_RXPLSEINT (0x00000008u)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C0_TXPLSEINT (0x00000009u)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C0_MISCINT (0x0000000au)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C1_RXTHPLSEINT (0x0000000bu)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C1_RXPLSEINT (0x0000000cu)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C1_TXPLSEINT (0x0000000du)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C1_MISCINT (0x0000000eu)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C2_RXTHPLSEINT (0x0000000fu)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C2_RXPLSEINT (0x00000010u)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C2_TXPLSEINT (0x00000011u)
#define SYSCFG_CFGCHIP1_CAP1SRC_EMAC_C2_MISCINT (0x00000012u)

#define SYSCFG_CFGCHIP1_CAP0SRC (0x003E0000u)
#define SYSCFG_CFGCHIP1_CAP0SRC_SHIFT (0x00000011u)
/*----CAP0SRC Tokens----*/
#define SYSCFG_CFGCHIP1_CAP0SRC_ECAP0 (0x00000000u)
#define SYSCFG_CFGCHIP1_CAP0SRC_MCASP0_TXDMA (0x00000001u)
#define SYSCFG_CFGCHIP1_CAP0SRC_MCASP0_RXDMA (0x00000002u)
#define SYSCFG_CFGCHIP1_CAP0SRC_MCASP1_TXDMA (0x00000003u)
#define SYSCFG_CFGCHIP1_CAP0SRC_MCASP1_RXDMA (0x00000004u)
#define SYSCFG_CFGCHIP1_CAP0SRC_MCASP2_TXDMA (0x00000005u)
#define SYSCFG_CFGCHIP1_CAP0SRC_MCASP2_RXDMA (0x00000006u)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C0_RXTHPLSEINT (0x00000007u)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C0_RXPLSEINT (0x00000008u)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C0_TXPLSEINT (0x00000009u)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C0_MISCINT (0x0000000au)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C1_RXTHPLSEINT (0x0000000bu)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C1_RXPLSEINT (0x0000000cu)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C1_TXPLSEINT (0x0000000du)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C1_MISCINT (0x0000000eu)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C2_RXTHPLSEINT (0x0000000fu)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C2_RXPLSEINT (0x00000010u)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C2_TXPLSEINT (0x00000011u)
#define SYSCFG_CFGCHIP1_CAP0SRC_EMAC_C2_MISCINT (0x00000012u)

#define SYSCFG_CFGCHIP1_HPIBYTEAD (0x00010000u)
#define SYSCFG_CFGCHIP1_HPIBYTEAD_SHIFT (0x00000010u)

#define SYSCFG_CFGCHIP1_HPIENA  (0x00008000u)
#define SYSCFG_CFGCHIP1_HPIENA_SHIFT (0x0000000Fu)

#define SYSCFG_CFGCHIP1_EDMA31TC0DBS (0x00006000u)
#define SYSCFG_CFGCHIP1_EDMA31TC0DBS_SHIFT (0x0000000Du)
/*----EDMA31TC0DBS Tokens----*/
#define SYSCFG_CFGCHIP1_EDMA31TC0DBS_16BYTE (0x00000000u)
#define SYSCFG_CFGCHIP1_EDMA31TC0DBS_32BYTE (0x00000001u)
#define SYSCFG_CFGCHIP1_EDMA31TC0DBS_64BYTE (0x00000002u)
#define SYSCFG_CFGCHIP1_EDMA31TC0DBS_RESERVED (0x00000003u)

#define SYSCFG_CFGCHIP1_TBCLKSYNC (0x00001000u)
#define SYSCFG_CFGCHIP1_TBCLKSYNC_SHIFT (0x0000000Cu)


#define SYSCFG_CFGCHIP1_AMUTESEL0 (0x0000000Fu)
#define SYSCFG_CFGCHIP1_AMUTESEL0_SHIFT (0x00000000u)
/*----AMUTESEL0 Tokens----*/
#define SYSCFG_CFGCHIP1_AMUTESEL0_LOW (0x00000000u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B0 (0x00000001u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B1 (0x00000002u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B2 (0x00000003u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B3 (0x00000004u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B4 (0x00000005u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B5 (0x00000006u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B6 (0x00000007u)
#define SYSCFG_CFGCHIP1_AMUTESEL0_GPIO_B7 (0x00000008u)


/* CFGCHIP2 */


#define SYSCFG_CFGCHIP2_USB0PHYCLKGD (0x00020000u)
#define SYSCFG_CFGCHIP2_USB0PHYCLKGD_SHIFT (0x00000011u)

#define SYSCFG_CFGCHIP2_USB0VBUSSENSE (0x00010000u)
#define SYSCFG_CFGCHIP2_USB0VBUSSENSE_SHIFT (0x00000010u)

#define SYSCFG_CFGCHIP2_RESET   (0x00008000u)
#define SYSCFG_CFGCHIP2_RESET_SHIFT  (0x0000000Fu)

#define SYSCFG_CFGCHIP2_USB0OTGMODE (0x00006000u)
#define SYSCFG_CFGCHIP2_USB0OTGMODE_SHIFT (0x0000000Du)
/*----USB0OTGMODE Tokens----*/
#define SYSCFG_CFGCHIP2_USB0OTGMODE_PHY (0x00000000u)
#define SYSCFG_CFGCHIP2_USB0OTGMODE_USB_HOST (0x00000001u)
#define SYSCFG_CFGCHIP2_USB0OTGMODE_USB_DEVICE (0x00000002u)
#define SYSCFG_CFGCHIP2_USB0OTGMODE_USB_HOST_LOW (0x00000003u)

#define SYSCFG_CFGCHIP2_USB1PHYCLKMUX (0x00001000u)
#define SYSCFG_CFGCHIP2_USB1PHYCLKMUX_SHIFT (0x0000000Cu)

#define SYSCFG_CFGCHIP2_USB0PHYCLKMUX (0x00000800u)
#define SYSCFG_CFGCHIP2_USB0PHYCLKMUX_SHIFT (0x0000000Bu)

#define SYSCFG_CFGCHIP2_USB0PHYPWDN (0x00000400u)
#define SYSCFG_CFGCHIP2_USB0PHYPWDN_SHIFT (0x0000000Au)

#define SYSCFG_CFGCHIP2_USB0OTGPWRDN (0x00000200u)
#define SYSCFG_CFGCHIP2_USB0OTGPWRDN_SHIFT (0x00000009u)

#define SYSCFG_CFGCHIP2_USB0DATPOL (0x00000100u)
#define SYSCFG_CFGCHIP2_USB0DATPOL_SHIFT (0x00000008u)

#define SYSCFG_CFGCHIP2_USB1SUSPENDM (0x00000080u)
#define SYSCFG_CFGCHIP2_USB1SUSPENDM_SHIFT (0x00000007u)

#define SYSCFG_CFGCHIP2_USB0PHY_PLLON (0x00000040u)
#define SYSCFG_CFGCHIP2_USB0PHY_PLLON_SHIFT (0x00000006u)

#define SYSCFG_CFGCHIP2_USB0SESNDEN (0x00000020u)
#define SYSCFG_CFGCHIP2_USB0SESNDEN_SHIFT (0x00000005u)

#define SYSCFG_CFGCHIP2_USB0VBDTCTEN (0x00000010u)
#define SYSCFG_CFGCHIP2_USB0VBDTCTEN_SHIFT (0x00000004u)

#define SYSCFG_CFGCHIP2_USB0REF_FREQ (0x0000000Fu)
#define SYSCFG_CFGCHIP2_USB0REF_FREQ_SHIFT (0x00000000u)


/* CFGCHIP3 */



#define SYSCFG_CFGCHIP3_RMII_SEL (0x00000100u)
#define SYSCFG_CFGCHIP3_RMII_SEL_SHIFT (0x00000008u)

#define SYSCFG_CFGCHIP3_UPP_TX_CLKSRC (0x00000040u)
#define SYSCFG_CFGCHIP3_UPP_TX_CLKSRC_SHIFT (0x00000006u)

#define SYSCFG_CFGCHIP3_PLL1_MASTER_LOCK (0x00000020u)
#define SYSCFG_CFGCHIP3_PLL1_MASTER_LOCK_SHIFT (0x00000005u)

#define SYSCFG_CFGCHIP3_ASYNC3_CLKSRC (0x00000010u)
#define SYSCFG_CFGCHIP3_ASYNC3_CLKSRC_SHIFT (0x00000004u)

#define SYSCFG_CFGCHIP3_PRUEVTSEL (0x00000008u)
#define SYSCFG_CFGCHIP3_PRUEVTSEL_SHIFT (0x00000003u)

#define SYSCFG_CFGCHIP3_DIV4P5ENA (0x00000004u)
#define SYSCFG_CFGCHIP3_DIV4P5ENA_SHIFT (0x00000002u)

#define SYSCFG_CFGCHIP3_EMA_CLKSRC (0x00000002u)
#define SYSCFG_CFGCHIP3_EMA_CLKSRC_SHIFT (0x00000001u)

#define SYSCFG_CFGCHIP4_AMUTECLR0 (0x00000001u)
#define SYSCFG_CFGCHIP4_AMUTECLR0_SHIFT (0x00000000u)

#ifdef __cplusplus
}
#endif

#endif  /* _HW_SYSCFG1_H_ */
